==> operation-csv-1.0.0-2.17.0-sources.jar: org/gcube/data/analysis/tabulardata/operation/csv/exporter/CSVExportFactory.java <==
package org.gcube.data.analysis.tabulardata.operation.csv.exporter;

import static org.gcube.data.analysis.tabulardata.operation.csv.Constants.ENCODING;
import static org.gcube.data.analysis.tabulardata.operation.csv.Constants.SEPARATOR;

import java.util.Collections;
import java.util.List;
import java.util.Locale;

import javax.inject.Inject;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.cube.data.connection.DatabaseConnectionProvider;
import org.gcube.data.analysis.tabulardata.model.column.Column;
import org.gcube.data.analysis.tabulardata.model.column.type.IdColumnType;
import org.gcube.data.analysis.tabulardata.model.metadata.common.NamesMetadata;
import org.gcube.data.analysis.tabulardata.model.table.Table;
import org.gcube.data.analysis.tabulardata.model.table.TableId;
import org.gcube.data.analysis.tabulardata.operation.factories.types.ExportWorkerFactory;
import org.gcube.data.analysis.tabulardata.operation.parameters.Cardinality;
import org.gcube.data.analysis.tabulardata.operation.parameters.Parameter;
import org.gcube.data.analysis.tabulardata.operation.parameters.leaves.BooleanParameter;
import org.gcube.data.analysis.tabulardata.operation.parameters.leaves.RegexpStringParameter;
import org.gcube.data.analysis.tabulardata.operation.worker.EligibleOperation;
import org.gcube.data.analysis.tabulardata.operation.worker.OperationDescriptor.OperationId;
import org.gcube.data.analysis.tabulardata.operation.worker.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.InvalidInvocationException;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.OperationNotEligibleException;

import com.google.common.collect.Lists;

public class CSVExportFactory extends ExportWorkerFactory {

	private static final OperationId OPERATION_ID = new OperationId(201);
	
	CubeManager cubeManager;
	
	DatabaseConnectionProvider connectionProvider;

	private static RegexpStringParameter separatorParameter= new RegexpStringParameter(SEPARATOR, "Separator", "Char separator", Cardinality.ONE, "\\W");
	
	private static RegexpStringParameter encodingParameter = new RegexpStringParameter(ENCODING, "Encoding", "Document Encoding", Cardinality.ONE, ".*");

	
	@Inject
	public CSVExportFactory(CubeManager cubeManager,
			DatabaseConnectionProvider connectionProvider) {
		if (cubeManager == null)
			throw new IllegalArgumentException("cubeManager cannot be null");
		if (connectionProvider == null)
			throw new IllegalArgumentException("connectionProvider cannot be null");
		this.cubeManager = cubeManager;
		this.connectionProvider = connectionProvider;
	}
	
	public EligibleOperation getEligibleOperation(TableId tableId) throws OperationNotEligibleException {
		return new EligibleOperation(getOperationDescriptor(), getParameters(tableId), tableId);
	}

	public Worker createWorker(OperationInvocation invocation) throws InvalidInvocationException {
		validateInvocation(invocation);
		return new CSVExport(invocation, cubeManager, connectionProvider);
	}

	@Override
	protected String getOperationName() {
		return "CSV Export";
	}

	@Override
	protected String getOperationDescription() {
		return "Export a table to a CSV file";
	}

	@Override
	protected OperationId getOperationId() {
		return OPERATION_ID;
	}

	private List<Parameter> getParameters(TableId tableId){
		List<Parameter> parameters = Lists.newArrayList();
		Collections.addAll(parameters, separatorParameter, encodingParameter);
		Table table =  cubeManager.getTable(tableId);
		for (Column column : table.getColumns())
			if (!(column.getColumnType() instanceof IdColumnType)){
				String label = column.getName();
				try{
					NamesMetadata metadata = ((NamesMetadata)column.getMetadata(NamesMetadata.class));
					if (metadata.hasTextWithLocale(Locale.ENGLISH))
						label = metadata.getTextWithLocale(Locale.ENGLISH).getValue();
				}catch (Exception e) {}
				parameters.add(new BooleanParameter(column.getName(), "column "+label+" export", "export selection for column "+label, Cardinality.ONE));
				
			}
		return parameters;
	}
	
	public void validateInvocation(OperationInvocation invocation) throws InvalidInvocationException{
		if (invocation==null) throw new InvalidInvocationException(invocation, "null invocation");
		checkTableIdPresence(invocation);
		if (!encodingParameter.validate((String)invocation.getParameterInstances().get(ENCODING))) throw new InvalidInvocationException(invocation, "encoding not valid");
		if (!separatorParameter.validate((String)invocation.getParameterInstances().get(SEPARATOR))) throw new InvalidInvocationException(invocation, "separator not valid");
		
		Table table = cubeManager.getTable(invocation.getTargetTableId());
		for (Column column : table.getColumns())
			if (!(column.getColumnType() instanceof IdColumnType) && 
					!invocation.getParameterInstances().containsKey(column.getName()))
				throw new InvalidInvocationException(invocation, String.format("column %s not found", column.getName()));
		
	}
}

==> operation-csv-1.1.0-20140211.101457-1-sources.jar: org/gcube/data/analysis/tabulardata/operation/csv/exporter/CSVExportFactory.java <==
package org.gcube.data.analysis.tabulardata.operation.csv.exporter;

import static org.gcube.data.analysis.tabulardata.operation.csv.Constants.*;

import java.util.Collections;
import java.util.List;
import javax.inject.Inject;
import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.cube.data.connection.DatabaseConnectionProvider;
import org.gcube.data.analysis.tabulardata.operation.OperationId;
import org.gcube.data.analysis.tabulardata.operation.factories.types.ExportWorkerFactory;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.parameters.Cardinality;
import org.gcube.data.analysis.tabulardata.operation.parameters.Parameter;
import org.gcube.data.analysis.tabulardata.operation.parameters.leaves.RegexpStringParameter;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.InvalidInvocationException;
import com.google.common.collect.Lists;

public class CSVExportFactory extends ExportWorkerFactory {

	private static final String OPERATION_NAME = "CSV Export";
	
	private static final OperationId OPERATION_ID = new OperationId(101);
	
	CubeManager cubeManager;
	
	DatabaseConnectionProvider connectionProvider;

	private static RegexpStringParameter separatorParameter= new RegexpStringParameter(SEPARATOR, "Separator", "Char separator", Cardinality.ONE, "\\W$");
	
	private static RegexpStringParameter encodingParameter = new RegexpStringParameter(ENCODING, "Encoding", "Document Encoding", Cardinality.ONE, ".*");

	private static RegexpStringParameter columnsParameter = new RegexpStringParameter(COLUMNS, "Columns", "Selected Columns", new Cardinality(1,1000) , ".*");
	
	@Inject
	public CSVExportFactory(CubeManager cubeManager,
			DatabaseConnectionProvider connectionProvider) {
		if (cubeManager == null)
			throw new IllegalArgumentException("cubeManager cannot be null");
		if (connectionProvider == null)
			throw new IllegalArgumentException("connectionProvider cannot be null");
		this.cubeManager = cubeManager;
		this.connectionProvider = connectionProvider;
	}
	
	public Worker createWorker(OperationInvocation invocation) throws InvalidInvocationException {
		validateInvocation(invocation);
		return new CSVExport(invocation, cubeManager, connectionProvider);
	}

	@Override
	protected String getOperationName() {
		return OPERATION_NAME;
	}

	@Override
	protected String getOperationDescription() {
		return "Export a table to a CSV file";
	}

	@Override
	protected OperationId getOperationId() {
		return OPERATION_ID;
	}

	
	@Override
	public List<Parameter> getParameters(){
		List<Parameter> parameters = Lists.newArrayList();
		Collections.addAll(parameters, separatorParameter, encodingParameter, columnsParameter);
		return parameters;
	}
	
	public void validateInvocation(OperationInvocation invocation) throws InvalidInvocationException{
		if (invocation==null) throw new InvalidInvocationException(invocation, "null invocation");
		//this.checkTableIdPresence(invocation);
		if (!encodingParameter.validate((String)invocation.getParameterInstances().get(ENCODING))) throw new InvalidInvocationException(invocation, "encoding not valid");
		if (!separatorParameter.validate((String)invocation.getParameterInstances().get(SEPARATOR))) throw new InvalidInvocationException(invocation, "separator not valid");
		
		String[] columns = (String[])invocation.getParameterInstances().get(COLUMNS);
		if (columns==null || columns.length<=0) throw new InvalidInvocationException(invocation, "columns parameter not valid");
		
		/*TODO: check columns validity
		
		
		Table table = cubeManager.getTable(invocation.getTargetTableId());
		*/
		
	}
}
